@@ -8,11 +8,11 @@ from luscious_dl.downloader import Downloader
 from luscious_dl.logger import logger
 from luscious_dl.parser import extract_ids_from_list, extract_album_id, extract_user_id
 from luscious_dl.user import User
-from luscious_dl.utils import info, format_foldername, generate_pdf, inputs_string_to_list
+from luscious_dl.utils import info, format_foldername, generate_pdf, inputs_string_to_list, delete_folder, generate_cbz
 
 
 def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: Path,
-                    foldername_format='%t', gen_pdf=False, rm_origin_dir=False) -> None:
+                    foldername_format='%t', gen_pdf=False, gen_cbz=False, rm_origin_dir=False) -> None:
   """
   Start albums download process.
   :param albums_ids: list of album ids
@@ -20,6 +20,7 @@ def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: P
   :param foldername_format: album folder name format
   :param output_dir: Path where albums will be saved
   :param gen_pdf: indicates whether to generate the pdf file
+  :param gen_cbz: indicates whether to generate the cbz file
   :param rm_origin_dir: indicates whether the source folder will be deleted
   """
   for id_ in albums_ids:
@@ -33,7 +34,11 @@ def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: P
         # album.generate_metadata(album_folder)
         album.download(downloader, album_folder)
         if gen_pdf:
-          generate_pdf(output_dir, formmatted_foldername, album_folder, rm_origin_dir)
+          generate_pdf(output_dir, formmatted_foldername, album_folder)
+        if gen_cbz:
+          generate_cbz(output_dir, formmatted_foldername, album_folder)
+        if rm_origin_dir:
+          delete_folder(album_folder, formmatted_foldername)
       else:
         raise Exception('Album Information not found.')
     except Exception as e:
@@ -41,7 +46,8 @@ def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: P
 
 
 def users_download(users_ids: list[int], downloader: Downloader, output_dir: Path, foldername_format='%t',
-                   only_favorites=False, gen_pdf=False, rm_origin_dir=False, group_by_user=False) -> None:
+                   only_favorites=False, gen_pdf=False, gen_cbz=False, rm_origin_dir=False, group_by_user=False) -> \
+        None:
   """
   Start users download process.
   :param users_ids: list of user ids
@@ -50,6 +56,7 @@ def users_download(users_ids: list[int], downloader: Downloader, output_dir: Pat
   :param foldername_format: album folder name format
   :param only_favorites: defines if it's to download only the favorites
   :param gen_pdf: whether to generate the pdf file
+  :param gen_cbz: whether to generate the cbz file
   :param rm_origin_dir: indicates whether the source folder will be deleted
   :param group_by_user:
   """
@@ -61,7 +68,7 @@ def users_download(users_ids: list[int], downloader: Downloader, output_dir: Pat
         user.show()
         if group_by_user:
           output_dir = output_dir.joinpath(os.path.normcase(user.name))
-        albums_download(user.albums_ids, downloader, output_dir, foldername_format, gen_pdf, rm_origin_dir)
+        albums_download(user.albums_ids, downloader, output_dir, foldername_format, gen_pdf, gen_cbz, rm_origin_dir)
       else:
         raise Exception('User Information not found.')
     except Exception as e:
@@ -95,6 +102,15 @@ def normalize_args(args: Namespace) -> Namespace:
     logger.warn(f"You're passing --pdf flag without any album/user input or search download.")
     args.gen_pdf = False
 
+  if args.gen_cbz and not args.album_inputs and not args.user_inputs and not args.search_download:
+    logger.warn(f"You're passing --cbz flag without any album/user input or search download.")
+    args.gen_cbz = False
+
+  if args.rm_origin_dir and not args.gen_pdf and not args.gen_cbz:
+    logger.warn(f"You're passing --rm-origin-dir flag without any pdf or cbz generation. This would delete the album "
+                f"after download")
+    args.rm_origin_dir = False
+
   args.keyword = args.keyword.strip() if args.keyword else None
 
   if args.album_inputs:
@@ -121,10 +137,10 @@ def start(args: Namespace = None) -> None:
 
   if args.albums_ids:
     albums_download(args.albums_ids, downloader, args.output_dir, args.foldername_format,
-                    args.gen_pdf, args.rm_origin_dir)
+                    args.gen_pdf, args.gen_cbz, args.rm_origin_dir)
   elif args.users_ids:
     users_download(args.users_ids, downloader, args.output_dir, args.foldername_format,
-                   args.only_favorites, args.gen_pdf, args.rm_origin_dir, args.group_by_user)
+                   args.only_favorites, args.gen_pdf, args.gen_cbz, args.rm_origin_dir, args.group_by_user)
   elif args.keyword:
     result = search_albums(args.keyword, args.sorting, args.page, args.max_pages)
     print_search(result)
@@ -136,7 +152,7 @@ def start(args: Namespace = None) -> None:
         album_folder = Path.joinpath(args.output_dir, formmatted_foldername)
         album.download(downloader, album_folder)
         if args.gen_pdf:
-          generate_pdf(args.output_dir, formmatted_foldername, album_folder, args.rm_origin_dir)
+          generate_pdf(args.output_dir, formmatted_foldername, album_folder)
 
 
 if __name__ == '__main__':
